@@ -1,5 +1,5 @@
 from nautilus_librarian.mods.dvc.domain.utils import (
-    extract_list_of_media_file_changes_from_dvc_diff_output,
+    extract_all_added_and_modified_and_renamed_files_from_dvc_diff,
     get_new_filepath_if_is_a_renaming_dict,
 )
 from nautilus_librarian.mods.namecodes.domain.validate_filenames import (
@@ -15,12 +15,16 @@ from nautilus_librarian.typer.commands.workflows.actions.action_result import (
 
 def validate_filenames(dvc_diff):
     """
-    It validates all the media file names in the dvc diff.
+    It validates all the filenames in the dvc diff.
     """
     if dvc_diff == "{}":
-        return ActionResult(ResultCode.EXIT, [Message("No Gold image changes found")])
+        return ActionResult(
+            ResultCode.EXIT, [Message("No filenames to validate, empty DVC diff")]
+        )
 
-    filenames = extract_list_of_media_file_changes_from_dvc_diff_output(dvc_diff)
+    # TODO: we have to review this function if we add files to DVC which do not belong to a media library.
+
+    filenames = extract_all_added_and_modified_and_renamed_files_from_dvc_diff(dvc_diff)
 
     messages = []
 
