@@ -3,28 +3,38 @@ from test_nautilus_librarian.utils import compact_json
 from nautilus_librarian.mods.dvc.domain.utils import (
     extract_added_files_from_dvc_diff,
     extract_deleted_files_from_dvc_diff,
-    extract_list_of_media_file_changes_from_dvc_diff_output,
+    extract_list_of_new_or_renamed_files_from_dvc_diff_output,
     extract_modified_files_from_dvc_diff,
     extract_renamed_files_from_dvc_diff,
     get_new_filepath_if_is_a_renaming_dict,
 )
 
 
-def test_extract_list_of_media_file_changes_from_dvc_diff_output():
+def test_extract_list_of_new_or_renamed_files_from_dvc_diff_output():
     dvc_diff = {
         "added": [
             {"path": "data/000001/32/000001-32.600.2.tif"},
         ],
         "deleted": [],
         "modified": [],
-        "renamed": [],
+        "renamed": [
+            {
+                "path": {
+                    "old": "data/000003/32/000003-32.600.2.tif",
+                    "new": "data/000002/32/000002-32.600.2.tif",
+                }
+            }
+        ],
     }
 
-    filenames = extract_list_of_media_file_changes_from_dvc_diff_output(
+    filenames = extract_list_of_new_or_renamed_files_from_dvc_diff_output(
         compact_json(dvc_diff)
     )
 
-    assert filenames == ["000001-32.600.2.tif"]
+    assert filenames == [
+        "data/000001/32/000001-32.600.2.tif",
+        "data/000002/32/000002-32.600.2.tif",  # We include only the new name of the file for renamed ones.
+    ]
 
 
 def test_extract_added_files_from_dvc_diff():
